@@ -1,18 +1,14 @@
 package DBIx::Class::Migration;
 
-our $VERSION = "0.067";
+our $VERSION = "0.068";
 $VERSION = eval $VERSION;
 
-use Moose;
+use Moo;
 use JSON::MaybeXS qw(JSON);
 use File::Copy 'cp';
 use File::Spec::Functions 'catdir', 'catfile', 'updir';
 use File::Path 'mkpath', 'remove_tree';
-use DBIx::Class::Migration::Types qw(
-  LoadableClass LoadableDBICSchemaClass
-  AbsolutePath
-);
-use Class::Load 'load_class';
+use DBIx::Class::Migration::Types -all;
 use Devel::PartialDump;
 use SQL::Translator;
 use Log::Any '$log', default_adapter => 'Stderr';
@@ -28,17 +24,16 @@ has db_sandbox_class => (
   is => 'ro',
   default => 'DBIx::Class::Migration::SqliteSandbox',
   isa => LoadableClass,
-  coerce => 1);
+);
 
-has db_sandbox => (is=>'ro', lazy_build=>1);
+has db_sandbox => (is=>'lazy');
 
-has db_sandbox_dir => (is=>'ro', predicate=>'has_db_sandbox_dir', isa=>'Str');
+has db_sandbox_dir => (is=>'ro', predicate=>'has_db_sandbox_dir', isa=>Str);
 
 has db_sandbox_builder_class => (
-  is => 'ro',
+  is => 'lazy',
   isa => LoadableClass,
-  lazy_build => 1,
-  coerce=>1);
+);
 
   sub _build_db_sandbox_builder_class {
     my $self = shift;
@@ -47,7 +42,7 @@ has db_sandbox_builder_class => (
         'DBIx::Class::Migration::TargetDirSandboxBuilder';
   }
 
-has db_sandbox_builder => (is=>'ro', lazy_build=>1);
+has db_sandbox_builder => (is=>'lazy');
 
   sub _build_db_sandbox_builder {
     my $self = shift;
@@ -66,13 +61,13 @@ has schema_class => (
   isa => LoadableDBICSchemaClass,
   coerce=>1);
 
-has schema_args => (is=>'ro', isa=>'ArrayRef', lazy_build=>1);
+has schema_args => (is=>'lazy', isa=>ArrayRef);
 
   sub _build_schema_args {
     +[ shift->db_sandbox->make_sandbox ];
   }
 
-has schema => (is=>'ro', lazy_build=>1, predicate=>'has_schema');
+has schema => (is=>'lazy', predicate=>'has_schema');
 
   sub _build_schema {
     my ($self) = @_;
@@ -83,9 +78,9 @@ has target_dir_builder_class => (
   is => 'ro',
   default => 'DBIx::Class::Migration::ShareDirBuilder',
   isa => LoadableClass,
-  coerce=>1);
+);
 
-has target_dir_builder => ( is => 'ro', lazy_build => 1);
+has target_dir_builder => (is => 'lazy');
 
   sub _infer_schema_class {
     my $self = shift;
@@ -102,13 +97,16 @@ has target_dir_builder => ( is => 'ro', lazy_build => 1);
       ->new(schema_class=>$inferred_schema_class);
   }
 
-has target_dir => (is => 'ro', isa=> AbsolutePath, coerce => 1, lazy_build=>1);
+has target_dir => (is => 'lazy', isa=> AbsolutePath, coerce => 1);
 
   sub _build_target_dir {
     shift->target_dir_builder->build;
   }
 
-has dbic_dh_args => (is=>'rw', isa=>'HashRef', lazy_build=>1);
+has dbic_dh_args => (
+  is=>'rw', isa=>HashRef,
+  lazy => 1, builder => '_build_dbic_dh_args',
+);
 
   sub _build_dbic_dh_args {
     +{ sql_translator_args => { quote_identifiers => 1 } }
@@ -118,9 +116,9 @@ has schema_loader_class => (
   is => 'ro',
   default => 'DBIx::Class::Migration::SchemaLoader',
   isa => LoadableClass,
-  coerce=>1);
+);
 
-has schema_loader => (is=>'ro', lazy_build=>1);
+has schema_loader => (is=>'lazy');
 
   sub _build_schema_loader {
     my $self = shift;
@@ -132,9 +130,9 @@ has dbic_fixture_class => (
   is => 'ro',
   default => 'DBIx::Class::Fixtures',
   isa => LoadableClass,
-  coerce=>1);
+);
 
-has dbic_fixtures_extra_args => ( is=>'ro', isa=>'HashRef', lazy_build=>1);
+has dbic_fixtures_extra_args => (is=>'lazy', isa=>HashRef);
 
   sub _build_dbic_fixtures_extra_args {
     return +{};
@@ -144,9 +142,9 @@ has deployment_handler_class => (
   is => 'ro',
   default => 'DBIx::Class::DeploymentHandler',
   isa => LoadableClass,
-  coerce=>1);
+);
 
-has extra_schemaloader_args => (is=>'ro', isa=>'HashRef', lazy_build=>1);
+has extra_schemaloader_args => (is=>'lazy', isa=>HashRef);
 
   sub _build_extra_schemaloader_args {
     return +{};
@@ -189,9 +187,6 @@ sub dbic_dh {
   my ($self, @args) = @_;
   my %dbic_dh_args = $self->normalized_dbic_dh_args;
 
-  (load_class "SQL::Translator::Producer::$_" ||
-    _log_die "No SQLT Producer for $_") for @{$dbic_dh_args{databases}};
-
   _log_die "A \$VERSION needs to be specified in your schema class ${\$self->_infer_schema_class}"
   unless $self->schema->schema_version;
 
@@ -1218,7 +1213,7 @@ missed you.
 =head1 SEE ALSO
 
 L<DBIx::Class::DeploymentHandler>, L<DBIx::Class::Fixtures>, L<DBIx::Class>,
-L<DBIx::Class::Schema::Loader>, L<Moose>, L<DBIx::Class::Migration::Script>,
+L<DBIx::Class::Schema::Loader>, L<Moo>, L<DBIx::Class::Migration::Script>,
 L<DBIx::Class::Migration::Population>, L<dbic-migration>, L<SQL::Translator>,
 L<Test::mysqld>, L<Test::Postgresql58>.
 
